@@ -29,7 +29,7 @@ class {package_name}Conan(Sense2File):
     # topics = ("<Put some tag here>", "<here>", "<and here>")
     settings = "os", "compiler", "build_type", "arch"
     options = {{"shared": [True, False], "fPIC": [True, False]}}
-    default_options = {{"shared": False, "fPIC": True}}
+    default_options = {{"shared": True, "fPIC": True}}
     generators = "cmake"
     requires = ""
     
